import { ServerData } from "rayconnect-client/dist/core/types"
import rayconnect from "rayconnect-client"

export default class raywordSdk{
    rayconnectApp:rayconnect
    scope:string
    user:string
    constructor(app:rayconnect){
        this.rayconnectApp=app
        this.scope="rayword"
        this.user="test_admin_system"
    }

    createItem<T>(model: string, data: T):Promise<T>{
        return this.rayconnectApp.Run({
            scope: this.scope,
            address: "create_item",
            user: this.user,
            token: "*",
            method: "CREATE",
            data: {
                model: model,
                values:data
            }}).then((value)=>{
                return (value as ServerData).data as Promise<T>
            })
    }

    readAllItem<T>(model:string):Promise<T[]>{
        return this.rayconnectApp.Run({
            scope: this.scope,
            address: "read_all_item",
            user: this.user,
            token: "*",
            method: "READ",
            data: {
                model: model,
                values: null
            }}).then((value)=>{
                return (value as ServerData).data as Promise<T[]>
            }) 
    }

    updateItem<T>(model: string, id: string, data: T):Promise<T>{
        return this.rayconnectApp.Run({
            scope: this.scope,
            address: "update_item",
            user: this.user,
            token: "*",
            method: "UPDATE",
            data: {
                model: model,
                id: id,
                values: data
            }}).then((value)=>{
                return (value as ServerData).data as Promise<T>
            })
    }

    deleteItem(model:string,id:string):object{
        return this.rayconnectApp.Run({
            scope: this.scope,
            address: "delete_item",
            user: this.user,
            token: "*",
            method: "DELETE",
            data: {
                model: model,
                values: id
            }}).then((value)=>{
                return (value as ServerData).data
            })
    }

    findItem<T>(model:string,id:string):Promise<T>{
        return this.rayconnectApp.Run({
            scope: this.scope,
            address: "find_item",
            user: this.user,
            token: "*",
            method: "FINDBYNAME",
            data: {
                model: model,
                values: id
            }}).then((value)=>{
                return (value as ServerData).data as Promise<T>
            })
    }

    findItemsByName<T>(model:string,name:string):Promise<T[]>{
        return this.rayconnectApp.Run({
            scope: this.scope,
            address: "find_items_by_name",
            user: this.user,
            token: "*",
            method: "FINDBYNAME",
            data: {
                model: model,
                values: name
            }}).then((value)=>{
                return (value as ServerData).data as Promise<T[]>
            })
    }
}

